@@ -457,7 +457,7 @@ class GXDLMSTranslator:
                             else:
                                 if data.command == Command.SNRM or data.command == Command.UA:
                                     xml.appendStartTag(data.command)
-                                    self.__pduToXml_(xml, data.data, True, True, True)
+                                    self._pduToXml2(xml, data.data, True, True, True)
                                     xml.appendEndTag(data.command)
                                     xml.setXmlLength(xml.getXmlLength() + 2)
                                 else:
@@ -472,26 +472,24 @@ class GXDLMSTranslator:
                 msg.xml = str(xml)
                 return msg.xml
             #  If wrapper.
-            if msg.interfaceType in (None, InterfaceType.WRAPPER) and msg.message.getUInt16(msg.message.position) == 1:
+            if msg.interfaceType in (None, InterfaceType.WRAPPER) and (msg.message.available() > 1) and msg.message.getUInt16(msg.message.position) == 1:
                 msg.interfaceType = settings.interfaceType = InterfaceType.WRAPPER
                 GXDLMS.getData(settings, msg.message, data, None)
                 msg.moreData = data.moreData
                 msg.sourceAddress = data.sourceAddress
                 msg.targetAddress = data.targetAddress
+                pdu = self.__pduToXml(data.data, self.omitXmlDeclaration, self.omitXmlNameSpace)
                 if not self.pduOnly:
                     xml.appendLine("<WRAPPER len=\"" + xml.integerToHex(data.packetLength - offset, 0) + "\" >")
                     xml.appendLine("<TargetAddress Value=\"" + xml.integerToHex(settings.clientAddress, 0) + "\" />")
                     xml.appendLine("<SourceAddress Value=\"" + xml.integerToHex(settings.serverAddress, 0) + "\" />")
-                if not data.data:
-                    xml.appendLine("<Command Value=\"" + Command.toString(data.command) + "\" />")
-                else:
-                    if not self.pduOnly:
-                        xml.appendLine("<PDU>")
-                    xml.appendLine(self.__pduToXml(data.data, True, True))
-                    #  Remove \r\n.
-                    xml.trim()
-                    if not self.pduOnly:
-                        xml.appendLine("</PDU>")
+                if not self.pduOnly:
+                    xml.appendLine("<PDU>")
+                xml.appendLine(pdu)
+                #  Remove \r\n.
+                xml.trim()
+                if not self.pduOnly:
+                    xml.appendLine("</PDU>")
                 if not self.pduOnly:
                     xml.appendLine("</WRAPPER>")
                 self.__updateAddress(settings, msg)
@@ -663,18 +661,18 @@ class GXDLMSTranslator:
     #
     def __pduToXml(self, value, omitDeclaration, omitNameSpace):
         xml = GXDLMSTranslatorStructure(self.outputType, self.omitXmlNameSpace, self.hex, self.showStringAsHex, self.comments, self.tags)
-        return self.__pduToXml_(xml, value, omitDeclaration, omitNameSpace, True)
+        return self._pduToXml2(xml, value, omitDeclaration, omitNameSpace, True)
 
     @classmethod
     def isCiphered(cls, cmd):
-        return cmd in (Command.GENERAL_GLO_CIPHERING, Command.GENERAL_DED_CIPHERING,\
-            Command.GLO_READ_REQUEST, Command.GLO_WRITE_REQUEST, Command.GLO_GET_REQUEST,\
+        return cmd in (Command.GLO_READ_REQUEST, Command.GLO_WRITE_REQUEST, Command.GLO_GET_REQUEST,\
             Command.GLO_SET_REQUEST, Command.GLO_READ_RESPONSE, Command.GLO_WRITE_RESPONSE,\
             Command.GLO_GET_RESPONSE, Command.GLO_SET_RESPONSE, Command.GLO_METHOD_REQUEST,\
             Command.GLO_METHOD_RESPONSE, Command.DED_GET_REQUEST, Command.DED_SET_REQUEST,\
             Command.DED_READ_RESPONSE, Command.DED_GET_RESPONSE, Command.DED_SET_RESPONSE,\
-            Command.DED_METHOD_REQUEST, Command.DED_METHOD_RESPONSE, Command.GLO_CONFIRMED_SERVICE_ERROR,\
-            Command.DED_CONFIRMED_SERVICE_ERROR, Command.GENERAL_CIPHERING)
+            Command.DED_METHOD_REQUEST, Command.DED_METHOD_RESPONSE, Command.GENERAL_GLO_CIPHERING,\
+            Command.GENERAL_DED_CIPHERING, Command.AARQ, Command.AARE, Command.GLO_CONFIRMED_SERVICE_ERROR,\
+            Command.DED_CONFIRMED_SERVICE_ERROR, Command.GENERAL_CIPHERING, Command.RELEASE_REQUEST)
 
     #
     # Convert bytes to XML.
@@ -683,7 +681,7 @@ class GXDLMSTranslator:
     #            Bytes to convert.
     # Converted XML.
     #
-    def __pduToXml_(self, xml, value, omitDeclaration, omitNameSpace, allowUnknownCommand=True):
+    def _pduToXml2(self, xml, value, omitDeclaration, omitNameSpace, allowUnknownCommand=True):
         #pylint: disable=bad-option-value,too-many-arguments,too-many-locals,
         #too-many-nested-blocks,redefined-variable-type
         if not value:
@@ -814,7 +812,7 @@ class GXDLMSTranslator:
                         if p.blockCipherKey:
                             data2 = GXByteBuffer(GXCiphering.decrypt(settings.cipher, p, value))
                             xml.startComment("Decrypt data: " + str(data2))
-                            self.__pduToXml_(xml, data2, omitDeclaration, omitNameSpace, False)
+                            self._pduToXml2(xml, data2, omitDeclaration, omitNameSpace, False)
                             xml.endComment()
                 except Exception:
                     #  It's OK if this fails.  Ciphering settings are not correct.
@@ -836,7 +834,7 @@ class GXDLMSTranslator:
                     tmp = GXByteBuffer(GXCiphering.decrypt(settings.cipher, p, tmp))
                     len_ = xml.getXmlLength()
                     xml.startComment("Decrypt data: " + str(tmp))
-                    self.__pduToXml_(xml, tmp, omitDeclaration, omitNameSpace, False)
+                    self._pduToXml2(xml, tmp, omitDeclaration, omitNameSpace, False)
                     xml.endComment()
                 except Exception:
                     #  It's OK if this fails.  Ciphering settings are not
@@ -871,7 +869,7 @@ class GXDLMSTranslator:
             xml.appendStartTag(cmd)
             xml.appendLine(TranslatorTags.NETWORK_ID, None, str(id_))
             xml.appendLine(TranslatorTags.PHYSICAL_DEVICE_ADDRESS, None, GXByteBuffer.hex(tmp, False, 0, len_))
-            self.__pduToXml_(xml, GXByteBuffer(value.remaining()), omitDeclaration, omitNameSpace, allowUnknownCommand)
+            self._pduToXml2(xml, GXByteBuffer(value.remaining()), omitDeclaration, omitNameSpace, allowUnknownCommand)
             xml.appendEndTag(cmd)
         elif cmd == Command.EXCEPTION_RESPONSE:
             data.xml = xml
